@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-from service.base import DataSource
+__author__ = r'wsb310@gmail.com'
 
 from hagworm.frame.fastapi.base import APIRouter, Request
 from hagworm.frame.fastapi.response import ErrorResponse
@@ -19,9 +19,3 @@ async def default(request: Request):
 async def error(request: Request):
 
     raise ErrorResponse(-1, request.client_ip, 400)
-
-
-@router.get(r'/health')
-async def health():
-
-    return await DataSource().health()
