@@ -2,13 +2,13 @@
 
 __author__ = r'wsb310@gmail.com'
 
+from hagworm.extend.trace import get_trace_id
 from hagworm.extend.error import Ignore, catch_error
 from hagworm.extend.metaclass import Singleton
 from hagworm.extend.asyncio.base import Utils, FuncCache, ShareFuture, MultiTasks
 from hagworm.extend.asyncio.cache import RedisDelegate
 from hagworm.extend.asyncio.database import MongoDelegate, MySQLDelegate
 from hagworm.extend.process import HeartbeatChecker
-from hagworm.frame.fastapi.middleware import REQUEST_ID_CONTEXT
 
 from setting import ConfigStatic, ConfigDynamic
 
@@ -112,9 +112,9 @@ class ServiceBase(Singleton, Utils):
         self._data_source = DataSource()
 
     @property
-    def request_id(self):
+    def trace_id(self):
 
-        return REQUEST_ID_CONTEXT.get(None)
+        return get_trace_id()
 
     def Break(self, *args, layers=1):
 
