@@ -4,17 +4,21 @@ __author__ = r'wsb310@gmail.com'
 
 import aioredis
 
+from contextvars import ContextVar
+
 from aioredis.util import _NOTSET
 from aioredis.pool import ConnectionsPool
 from aioredis.commands.string import StringCommandsMixin
 from aioredis.commands.transaction import Pipeline, MultiExec
 from aioredis.errors import ReplyError, MaxClientsError, AuthError, ReadOnlyError
 
-from .base import Utils, WeakContextVar, AsyncContextManager, AsyncCirculator
+from .base import Utils, WeakContextVar, AsyncCirculator
 from .event import DistributedEvent
 from .ntp import NTPClient
 from .transaction import Transaction
 
+from ..interface import AsyncContextManager
+
 
 REDIS_ERROR_RETRY_COUNT = 0x10
 REDIS_POOL_WATER_LEVEL_WARNING_LINE = 0x10
@@ -110,13 +114,27 @@ class RedisDelegate:
 
         self._redis_pool = None
 
-        self._cache_client_context = WeakContextVar(f'cache_client_{Utils.uuid1()}')
+        context_uuid = Utils.uuid1()
+
+        self._cache_client_context_switch = ContextVar(f'cache_client_{context_uuid}_switch', default=True)
+
+        self._cache_client_context = WeakContextVar(f'cache_client_{context_uuid}')
 
     @property
     def redis_pool(self):
 
         return self._redis_pool
 
+    @property
+    def cache_client_context_switch(self):
+
+        return self._cache_client_context_switch.get()
+
+    @cache_client_context_switch.setter
+    def cache_client_context_switch(self, val):
+
+        return self._cache_client_context_switch.set(val)
+
     async def async_init_redis(self, *args, **kwargs):
 
         self._redis_pool = await RedisPool(*args, **kwargs)
@@ -140,7 +158,7 @@ class RedisDelegate:
 
         client = None
 
-        if alone:
+        if alone or not self.cache_client_context_switch:
 
             client = self._redis_pool.get_client()
 
@@ -243,7 +261,7 @@ class CacheClient(aioredis.Redis, AsyncContextManager):
                 await self._close_conn(True)
 
                 if times < REDIS_ERROR_RETRY_COUNT:
-                    Utils.log.exception(err)
+                    Utils.log.error(err)
                 else:
                     raise err
 
