@@ -13,7 +13,7 @@ from .base import install_uvloop, Utils
 
 from ..error import catch_error
 from ..process import fork_processes
-from ..logging import DEFAULT_LOG_FILE_ROTATOR
+from ..logging import DEFAULT_LOG_FILE_ROTATOR, DEFAULT_LOG_FILE_NAME, init_logger
 from ..interface import FunctorInterface, RunnableInterface
 from ..asyncio.zmq import Push, Pull
 
@@ -168,30 +168,22 @@ class Launcher(RunnableInterface):
     """
 
     def __init__(self,
-                 log_file_path=None, log_level=r'INFO',
-                 log_file_rotation=DEFAULT_LOG_FILE_ROTATOR, log_file_retention=0xff,
+                 log_level=r'info', log_handler=None, log_file_path=None, log_file_name=DEFAULT_LOG_FILE_NAME,
+                 log_file_rotation=DEFAULT_LOG_FILE_ROTATOR, log_file_retention=0xff, log_extra=None, log_enqueue=False,
                  daemon=None, debug=False
                  ):
 
-        if log_file_path:
-
-            _log_file_path = Utils.path.join(
-                log_file_path,
-                r'runtime_{time}.log'
-            )
-
-            Utils.log.add(
-                _log_file_path,
-                level=log_level,
-                enqueue=True,
-                backtrace=debug,
-                rotation=log_file_rotation,
-                retention=log_file_retention
-            )
-
-        else:
-
-            Utils.log.level(log_level)
+        init_logger(
+            level=log_level.upper(),
+            handler=log_handler,
+            file_path=log_file_path,
+            file_name=log_file_name,
+            file_rotation=log_file_rotation,
+            file_retention=log_file_retention,
+            extra=log_extra,
+            enqueue=log_enqueue,
+            debug=debug
+        )
 
         environment = Utils.environment()
 
