@@ -3,16 +3,16 @@
 __author__ = r'wsb310@gmail.com'
 
 import pytz
+import asyncio
 import logging
 
-from collections import OrderedDict
-
 from apscheduler.schedulers.asyncio import AsyncIOScheduler
 from apscheduler.triggers.cron import CronTrigger
 
+from ..trace import trace_wrapper
 from ..interface import TaskInterface
 
-from .base import Utils, FutureWithTask
+from .base import Utils, FutureWithTask, catch_error
 
 
 TIMEZONE = pytz.timezone(r'Asia/Shanghai')
@@ -46,17 +46,7 @@ class TaskAbstract(TaskInterface):
     @staticmethod
     def _func_wrapper(func, *args, **kwargs):
 
-        if Utils.is_coroutine_function(func):
-
-            if args or kwargs:
-                return Utils.func_partial(func, *args, **kwargs)
-            else:
-                return func
-
-        async def _wrapper():
-            return func(*args, **kwargs)
-
-        return _wrapper
+        return Utils.func_partial(trace_wrapper(func), *args, **kwargs)
 
     def is_running(self):
 
@@ -205,164 +195,49 @@ class RateLimiter:
     def __init__(self, running_limit, waiting_limit=0, timeout=0):
 
         self._running_limit = running_limit
-        self._waiting_limit = waiting_limit
 
         self._timeout = timeout
 
-        self._running_tasks = OrderedDict()
-        self._waiting_tasks = OrderedDict()
+        self._running_tasks = set()
+        self._waiting_tasks = asyncio.Queue(waiting_limit)
 
-    @property
-    def running_tasks(self):
-
-        return list(self._running_tasks.values())
-
-    @property
-    def running_length(self):
-
-        return len(self._running_tasks)
-
-    @property
-    def waiting_tasks(self):
-
-        return list(self._waiting_tasks.values())
-
-    @property
-    def waiting_length(self):
-
-        return len(self._waiting_tasks)
-
-    def _create_task(self, name, func, *args, **kwargs):
+    def _create_task(self, func, *args, **kwargs):
 
         if len(args) == 0 and len(kwargs) == 0:
-            return FutureWithTask(func, name)
+            return FutureWithTask(func)
         else:
-            return FutureWithTask(Utils.func_partial(func, *args, **kwargs), name)
+            return FutureWithTask(Utils.func_partial(func, *args, **kwargs))
 
-    def append(self, func, *args, **kwargs):
+    async def append(self, func, *args, **kwargs):
 
-        return self._append(None, func, *args, **kwargs)
+        task = self._create_task(func, *args, **kwargs)
 
-    def append_with_name(self, name, func, *args, **kwargs):
+        await asyncio.wait_for(self._waiting_tasks.put(task), self._timeout)
 
-        return self._append(name, func, *args, **kwargs)
-
-    def _append(self, name, func, *args, **kwargs):
-
-        task = None
-
-        task_tag = f"{name or r''} {func} {args or r''} {kwargs or r''}"
-
-        if name is None or ((name not in self._running_tasks) and (name not in self._waiting_tasks)):
-
-            if self._check_running_limit():
-
-                task = self._create_task(name, func, *args, **kwargs)
-                self._add_running_tasks(task)
-
-                Utils.log.debug(f'rate limit add running tasks: {task_tag}')
-
-            elif self._check_waiting_limit():
-
-                task = self._create_task(name, func, *args, **kwargs)
-                self._add_waiting_tasks(task)
-
-                Utils.log.debug(f'rate limit add waiting tasks: {task_tag}')
-
-            else:
-
-                Utils.log.warning(
-                    f'rate limit: {task_tag}\n'
-                    f'running: {self.running_length}/{self.running_limit}\n'
-                    f'waiting: {self.waiting_length}/{self.waiting_limit}'
-                )
-
-        else:
-
-            Utils.log.warning(f'rate limit duplicate: {task_tag}')
+        await self._fill_running_tasks()
 
         return task
 
-    @property
-    def running_limit(self):
+    async def _fill_running_tasks(self):
 
-        return self._running_limit
+        loop_time = Utils.loop_time()
 
-    @running_limit.setter
-    def running_limit(self, val):
+        while not self._waiting_tasks.empty() and self._running_limit > len(self._running_tasks):
 
-        self._running_limit = val
+            with catch_error():
 
-        self._recover_waiting_tasks()
+                task = await self._waiting_tasks.get()
 
-    def _check_running_limit(self):
-
-        return (self._running_limit <= 0) or (len(self._running_tasks) < self._running_limit)
-
-    @property
-    def waiting_limit(self):
-
-        return self._waiting_limit
-
-    @waiting_limit.setter
-    def waiting_limit(self, val):
-
-        self._waiting_limit = val
-
-        if len(self._waiting_tasks) > self._waiting_limit:
-            self._waiting_tasks = self._waiting_tasks[:self._waiting_limit]
-
-    def _check_waiting_limit(self):
-
-        return (self._waiting_limit <= 0) or (len(self._waiting_tasks) < self._waiting_limit)
-
-    @property
-    def timeout(self):
-
-        return self._timeout
-
-    @timeout.setter
-    def timeout(self, val):
-
-        self._timeout = val
-
-    def _check_timeout(self, task):
-
-        return (self._timeout <= 0) or ((Utils.loop_time() - task.build_time) < self._timeout)
-
-    def _add_running_tasks(self, task):
-
-        if not self._check_timeout(task):
-            task.cancel()
-            Utils.log.warning(f'rate limit timeout: {task.name} build_time:{task.build_time}')
-        elif task.name in self._running_tasks:
-            task.cancel()
-            Utils.log.warning(f'rate limit duplicate: {task.name}')
-        else:
-            task.add_done_callback(self._done_callback)
-            self._running_tasks[task.name] = task.run()
-
-    def _add_waiting_tasks(self, task):
-
-        if task.name not in self._waiting_tasks:
-            self._waiting_tasks[task.name] = task
-        else:
-            task.cancel()
-            Utils.log.warning(f'rate limit duplicate: {task.name}')
-
-    def _recover_waiting_tasks(self):
-
-        for _ in range(len(self._waiting_tasks)):
-
-            if self._check_running_limit():
-                item = self._waiting_tasks.popitem(False)
-                self._add_running_tasks(item[1])
-            else:
-                break
+                if (self._timeout <= 0) or ((loop_time - task.build_time) < self._timeout):
+                    task.add_done_callback(self._done_callback)
+                    self._running_tasks.add(task.run())
+                else:
+                    task.cancel()
+                    Utils.log.warning(f'rate limit timeout: {task} build_time:{task.build_time}')
 
     def _done_callback(self, task):
 
-        if task.name in self._running_tasks:
-            self._running_tasks.pop(task.name)
+        if task in self._running_tasks:
+            self._running_tasks.remove(task)
 
-        self._recover_waiting_tasks()
+        Utils.call_soon(self._fill_running_tasks)
