@@ -4,24 +4,23 @@ __author__ = r'wsb310@gmail.com'
 
 from fastapi.responses import UJSONResponse
 
+from ...extend.trace import get_trace_id
 from ...extend.error import Ignore
 from ...extend.struct import Result
 
-from .middleware import RequestIDMiddleware
-
 
 class Response(UJSONResponse):
 
     def __init__(self, content=None, status_code=200, *args, **kwargs):
 
-        self._request_id = RequestIDMiddleware.get_request_id()
+        self._trace_id = get_trace_id()
 
         super().__init__(content, status_code, *args, **kwargs)
 
     def render(self, content):
 
         return super().render(
-            Result(data=content, request_id=self._request_id)
+            Result(data=content, trace_id=self._trace_id)
         )
 
 
@@ -38,5 +37,5 @@ class ErrorResponse(Response, Ignore):
 
         return UJSONResponse.render(
             self,
-            Result(code=self._code, error=content, request_id=self._request_id)
+            Result(code=self._code, error=content, trace_id=self._trace_id)
         )
