@@ -6,11 +6,12 @@ import sys
 
 from terminal_table import Table
 
-from hagworm.extend.logging import DEFAULT_LOG_FILE_ROTATOR
-from hagworm.extend.interface import FunctorInterface, RunnableInterface
-from hagworm.extend.asyncio import command
-from hagworm.extend.asyncio.base import Utils, MultiTasks, AsyncCirculator
-from hagworm.extend.asyncio.zmq import Subscribe, PublishWithBuffer
+from ..extend.logging import DEFAULT_LOG_FILE_ROTATOR
+from ..extend.interface import FunctorInterface, RunnableInterface
+
+from ..extend.asyncio import command
+from ..extend.asyncio.base import Utils, MultiTasks, AsyncCirculator
+from ..extend.asyncio.zmq import Subscribe, PublishWithBuffer
 
 
 SIGNAL_PROTOCOL = r'tcp'
